再帰呼び出しを全自動でloopに直すツールです。
関数呼び出しの深さが非常に深くなっても正常に実行できます。

This is a tool to fix recursive calls to loop in a fully automatic manner.
It can execute successfully even when the depth of the function call is very deep.



This description is under construction.
